@@ -315,27 +315,24 @@ class Store:
         self.store_file.flush()
         return store_position
 
-    def read(self, position, c_list=None):
-        self.store_file.seek(position)
-        tombstone = self.store_file.read(1)
-        type_bit = self.store_file.read(1).decode()
-        data = self.__read_until(b'\x1F')
-        length = int(data)
-        record = marshal.loads(self.store_file.read(length))
-        self.logger.debug("STORE READ: " + str(record) + " type bit: "+type_bit)
+    def read(self, position):
+        tombstone, type_bit, record = self.__read_block(position)
 
         if type_bit == 'l':
             prev_pointer = self.__read_until(b'\x1E')
             prev_pointer = int(prev_pointer) if prev_pointer != '' else -1
-            if c_list is None:
-                c_list = [record[1]]
-            else:
+            c_list = [record[1]]
+            key = record[0]
+
+            while prev_pointer > -1:
+                self.logger.debug("STORE READ: look for prev pointer: "+str(prev_pointer))
+                tombstone, type_bit, record = self.__read_block(prev_pointer)
                 c_list.append(record[1])
-            self.logger.debug("STORE READ: look for prev pointer: "+str(prev_pointer))
-            if prev_pointer < 0:
-                self.logger.debug("STORE READ: list read terminating, returning: "+str((record[0], c_list)))
-                return tombstone, (record[0], c_list)
-            return self.read(prev_pointer, c_list) #recursion limit of 1000!
+                prev_pointer = self.__read_until(b'\x1E')
+                prev_pointer = int(prev_pointer) if prev_pointer != '' else -1
+
+            self.logger.debug("STORE READ: list read terminating, returning: "+str((record[0], c_list)))
+            return tombstone, (key, c_list)
         else:
             return tombstone, record
 
@@ -350,6 +347,15 @@ class Store:
                 return None
         return b''.join(data).decode()
 
+    def __read_block(self, position):
+        self.store_file.seek(position)
+        tombstone = self.store_file.read(1)
+        type_bit = self.store_file.read(1).decode()
+        data = self.__read_until(b'\x1F')
+        length = int(data)
+        record = marshal.loads(self.store_file.read(length))
+        self.logger.debug("STORE READ: " + str(record) + " type bit: "+type_bit)
+        return tombstone, type_bit, record
 
 
 class Indexer:
