@@ -17,7 +17,7 @@ class TestLib(unittest.TestCase):
 
     def test_db(self):
         data = Record('testKey','testVal')
-        cogdb = Cog("/tmp/"+DIR_NAME+"/test")
+        cogdb = Cog()
         cogdb.create_namespace("test")
         cogdb.create_table("db_test", "test")
         cogdb.put(data)
